@@ -1,8 +1,9 @@
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 package CPAN::Meta;
-our $VERSION = '2.141170'; # VERSION
+
+our $VERSION = '2.150011';
 
 #pod =head1 SYNOPSIS
 #pod
@@ -397,7 +398,6 @@ sub save {
   my ($self, $file, $options) = @_;
 
   my $version = $options->{version} || '2';
-  my $layer = $] ge '5.008001' ? ':utf8' : '';
 
   if ( $version ge '2' ) {
     carp "'$file' should end in '.json'"
@@ -409,7 +409,7 @@ sub save {
   }
 
   my $data = $self->as_string( $options );
-  open my $fh, ">$layer", $file
+  open my $fh, '>:encoding(UTF-8)', $file
     or die "Error opening '$file' for writing: $!\n";
 
   print {$fh} $data;
@@ -465,7 +465,8 @@ sub effective_prereqs {
 #pod
 #pod This method returns true if the given file should be indexed.  It decides this
 #pod by checking the C<file> and C<directory> keys in the C<no_index> property of
-#pod the distmeta structure.
+#pod the distmeta structure. Note that neither the version format nor
+#pod C<release_status> are considered.
 #pod
 #pod C<$filename> should be given in unix format.
 #pod
@@ -492,7 +493,8 @@ sub should_index_file {
 #pod
 #pod This method returns true if the given package should be indexed.  It decides
 #pod this by checking the C<package> and C<namespace> keys in the C<no_index>
-#pod property of the distmeta structure.
+#pod property of the distmeta structure. Note that neither the version format nor
+#pod C<release_status> are considered.
 #pod
 #pod =cut
 
@@ -588,6 +590,10 @@ sub as_struct {
 #pod both cases, the same rules are followed as in the C<save()> method for choosing
 #pod a serialization backend.
 #pod
+#pod The serialized structure will include a C<x_serialization_backend> entry giving
+#pod the package and version used to serialize.  Any existing key in the given
+#pod C<$meta> object will be clobbered.
+#pod
 #pod =cut
 
 sub as_string {
@@ -607,10 +613,14 @@ sub as_string {
   my ($data, $backend);
   if ( $version ge '2' ) {
     $backend = Parse::CPAN::Meta->json_backend();
+    local $struct->{x_serialization_backend} = sprintf '%s version %s',
+      $backend, $backend->VERSION;
     $data = $backend->new->pretty->canonical->encode($struct);
   }
   else {
     $backend = Parse::CPAN::Meta->yaml_backend();
+    local $struct->{x_serialization_backend} = sprintf '%s version %s',
+      $backend, $backend->VERSION;
     $data = eval { no strict 'refs'; &{"$backend\::Dump"}($struct) };
     if ( $@ ) {
       croak $backend->can('errstr') ? $backend->errstr : $@
@@ -629,8 +639,6 @@ sub TO_JSON {
 
 # ABSTRACT: the distribution metadata for a CPAN dist
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -641,7 +649,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.141170
+version 2.150011
 
 =head1 SYNOPSIS
 
@@ -799,7 +807,8 @@ distribution's core prereqs before the CPAN::Meta::Prereqs object is returned.
 
 This method returns true if the given file should be indexed.  It decides this
 by checking the C<file> and C<directory> keys in the C<no_index> property of
-the distmeta structure.
+the distmeta structure. Note that neither the version format nor
+C<release_status> are considered.
 
 C<$filename> should be given in unix format.
 
@@ -809,7 +818,8 @@ C<$filename> should be given in unix format.
 
 This method returns true if the given package should be indexed.  It decides
 this by checking the C<package> and C<namespace> keys in the C<no_index>
-property of the distmeta structure.
+property of the distmeta structure. Note that neither the version format nor
+C<release_status> are considered.
 
 =head2 features
 
@@ -854,6 +864,10 @@ JSON.  For C<version> less than 2, the string will be serialized as YAML.  In
 both cases, the same rules are followed as in the C<save()> method for choosing
 a serialization backend.
 
+The serialized structure will include a C<x_serialization_backend> entry giving
+the package and version used to serialize.  Any existing key in the given
+C<$meta> object will be clobbered.
+
 =head1 STRING DATA
 
 The following methods return a single value, which is the value for the
@@ -985,7 +999,7 @@ L<CPAN::Meta::Validator>
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -1016,10 +1030,16 @@ David Golden <dagolden@cpan.org>
 
 Ricardo Signes <rjbs@cpan.org>
 
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
 =back
 
 =head1 CONTRIBUTORS
 
+=for stopwords Ansgar Burchardt Avar Arnfjord Bjarmason Benjamin Noggle Christopher J. Madsen Chuck Adams Cory G Watson Damyan Ivanov Dan Book Eric Wilhelm Graham Knop Gregor Hermann Karen Etheridge Kenichi Ishigaki Kent Fredric Ken Williams Lars Dieckow Leon Timmermans majensen Mark Fowler Matt S Trout Michael G. Schwern Mohammad Anwar mohawk2 moznion Niko Tyni Olaf Alders Olivier Mengué Philippe Bruhat (BooK) Randy Sims Ricardo Signes Tomohiro Hosaka
+
 =over 4
 
 =item *
@@ -1032,6 +1052,10 @@ Avar Arnfjord Bjarmason <avar@cpan.org>
 
 =item *
 
+Benjamin Noggle <agwind@users.noreply.github.com>
+
+=item *
+
 Christopher J. Madsen <cjm@cpan.org>
 
 =item *
@@ -1048,10 +1072,18 @@ Damyan Ivanov <dam@cpan.org>
 
 =item *
 
+Dan Book <grinnz@gmail.com>
+
+=item *
+
 Eric Wilhelm <ewilhelm@cpan.org>
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
 Gregor Hermann <gregoa@debian.org>
 
 =item *
@@ -1060,11 +1092,15 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Ken Williams <kwilliams@cpan.org>
+Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
 
-Kenichi Ishigaki <ishigaki@cpan.org>
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
+Ken Williams <kwilliams@cpan.org>
 
 =item *
 
@@ -1076,6 +1112,10 @@ Leon Timmermans <leont@cpan.org>
 
 =item *
 
+majensen <maj@fortinbras.us>
+
+=item *
+
 Mark Fowler <markf@cpan.org>
 
 =item *
@@ -1088,11 +1128,31 @@ Michael G. Schwern <mschwern@cpan.org>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
+mohawk2 <mohawk2@users.noreply.github.com>
+
+=item *
+
+moznion <moznion@gmail.com>
+
+=item *
+
+Niko Tyni <ntyni@debian.org>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
-Olivier Mengue <dolmen@cpan.org>
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Philippe Bruhat (BooK) <book@cpan.org>
 
 =item *
 
@@ -1100,15 +1160,24 @@ Randy Sims <randys@thepierianspring.org>
 
 =item *
 
-moznion <moznion@gmail.com>
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
+Tomohiro Hosaka <bokutin@bokut.in>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by David Golden and Ricardo Signes.
+This software is copyright (c) 2010 by David Golden, Ricardo Signes, Adam Kennedy and Contributors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+
+# vim: ts=2 sts=2 sw=2 et :
