@@ -1,8 +1,9 @@
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 package CPAN::Meta::Feature;
-our $VERSION = '2.141170'; # VERSION
+
+our $VERSION = '2.150011';
 
 use CPAN::Meta::Prereqs;
 
@@ -66,8 +67,6 @@ sub prereqs     { $_[0]{prereqs} }
 
 # ABSTRACT: an optional feature provided by a CPAN distribution
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -78,7 +77,7 @@ CPAN::Meta::Feature - an optional feature provided by a CPAN distribution
 
 =head1 VERSION
 
-version 2.141170
+version 2.150011
 
 =head1 DESCRIPTION
 
@@ -133,13 +132,22 @@ David Golden <dagolden@cpan.org>
 
 Ricardo Signes <rjbs@cpan.org>
 
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by David Golden and Ricardo Signes.
+This software is copyright (c) 2010 by David Golden, Ricardo Signes, Adam Kennedy and Contributors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+
+# vim: ts=2 sts=2 sw=2 et :
