@@ -3,11 +3,12 @@
 # that change semantics are not acceptable without prior approval
 # by David Golden or Ricardo Signes.
 
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 package CPAN::Meta::Spec;
-our $VERSION = '2.141170'; # VERSION
+
+our $VERSION = '2.150011';
 
 1;
 
@@ -28,7 +29,7 @@ CPAN::Meta::Spec - specification for CPAN distribution metadata
 
 =head1 VERSION
 
-version 2.141170
+version 2.150011
 
 =head1 SYNOPSIS
 
@@ -143,7 +144,8 @@ serializes into a bytestream and/or writes it to disk.
 
 =item must, should, may, etc.
 
-These terms are interpreted as described in IETF RFC 2119.
+These terms are interpreted as described in
+L<IETF RFC 2119|https://www.ietf.org/rfc/rfc2119.txt>.
 
 =back
 
@@ -158,7 +160,8 @@ constraints on the values of a data element.
 =head2 Boolean
 
 A I<Boolean> is used to provide a true or false value.  It B<must> be
-represented as a defined value.
+represented as a defined value that is either "1" or "0" or stringifies
+to those values.
 
 =head2 String
 
@@ -526,7 +529,10 @@ Example:
 
 This Map describes any files, directories, packages, and namespaces that
 are private to the packaging or implementation of the distribution and
-should be ignored by indexing or search tools.
+should be ignored by indexing or search tools. Note that this is a list of
+exclusions, and the spec does not define what to I<include> - see
+L</Indexing distributions a la PAUSE> in the implementors notes for more
+information.
 
 Valid subkeys are as follows:
 
@@ -696,7 +702,8 @@ have a Map with the following valid subkeys:
 
 This field is required.  It must contain a Unix-style relative file path
 from the root of the distribution directory to a file that contains or
-generates the package.
+generates the package.  It may be given as C<META.yml> or C<META.json>
+to claim a package for indexing without needing a C<*.pm>.
 
 =item version
 
@@ -1080,7 +1087,7 @@ other methods for locating a module in C<@INC>.
 
 If only a filename is available, the following approach may be used:
 
-  # via Module::Build
+  # via Module::Metadata
   my $info = Module::Metadata->new_from_file($file);
   my $version = $info->version;
 
@@ -1098,16 +1105,25 @@ ordinary comparison operators.  For example:
   }
 
 If the only comparison needed is whether an installed module is of a
-sufficiently high version, a direct test may be done using the string
-form of C<eval> and the C<use> function.  For example, for module C<$mod>
-and version prerequisite C<$prereq>:
+sufficiently high version, a direct test may be done using the C<VERSION>
+method.  For example, for module C<$mod> and version prerequisite
+C<$prereq>:
 
-  if ( eval "use $mod $prereq (); 1" ) {
+  use Module::Load 'load';
+  if ( $mod =~ m/\A[\w:']+\z/a and eval { load $mod; $mod->VERSION($prereq); 1 } ) {
     print "Module $mod version is OK.\n";
   }
 
-If the values of C<$mod> and C<$prereq> have not been scrubbed, however,
-this presents security implications.
+The regexp checks that C<$mod> only includes characters legal for module
+names before passing it to L<Module::Load/load>, which also accepts file
+paths that may escape C<@INC>.  Alternatively, if L<Module::Runtime> is
+installed, the C<use_module> function can load the module and perform the
+version check at the same time, and does not accept file paths:
+
+  use Module::Runtime 'use_module';
+  if ( eval { use_module $mod, $prereq; 1 } ) {
+    print "Module $mod version is OK.\n";
+  }
 
 =head2 Prerequisites for dynamically configured distributions
 
@@ -1137,6 +1153,24 @@ As such, consumers may use this data for informational analysis, but
 presenting it to the user as canonical or relying on it as such is
 invariably the height of folly.
 
+=head2 Indexing distributions a la PAUSE
+
+While no_index tells you what must be ignored when indexing, this spec holds
+no opinion on how you should get your initial candidate list of things to
+possibly index. For "normal" distributions you might consider simply indexing
+the contents of lib/, but there are many fascinating oddities on CPAN and
+many dists from the days when it was normal to put the main .pm file in the
+root of the distribution archive - so PAUSE currently indexes all .pm and .PL
+files that are not either (a) specifically excluded by no_index (b) in
+C<inc>, C<xt>, or C<t> directories, or common 'mistake' directories such as
+C<perl5>.
+
+Or: If you're trying to be PAUSE-like, make sure you skip C<inc>, C<xt> and
+C<t> as well as anything marked as no_index.
+
+Also remember: If the META file contains a provides field, you shouldn't be
+indexing anything in the first place - just use that.
+
 =head1 SEE ALSO
 
 =over 4
@@ -1173,6 +1207,10 @@ L<Module::Build>
 
 L<Module::Install>
 
+=item *
+
+L<CPAN::Meta::History::Meta_1_4>
+
 =back
 
 =head1 HISTORY
@@ -1200,11 +1238,15 @@ David Golden <dagolden@cpan.org>
 
 Ricardo Signes <rjbs@cpan.org>
 
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by David Golden and Ricardo Signes.
+This software is copyright (c) 2010 by David Golden, Ricardo Signes, Adam Kennedy and Contributors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
